YKStoreKit class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamSubscription ↔ StreamSubscription
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getDetail(
List< String> orderIds) → Future<List< YKStorePayDetail> > - 正在维护,暂停使用
-
order(
{required String orderId, required String customerId}) → Future -
requestReview(
) → Future< void> -
setupCheckOrder(
{required Future< bool> callBack(String protocol, String applePayId, String customerId)}) → dynamic -
setupDelegate(
{required YKStoreKitLogDelegate delegate}) → dynamic